@@ -196,11 +196,11 @@ class URDFModel(RobotModel):
         attrib = elem_link.attrib
         link_name = attrib.get('name', 'link_' + str(idx))
         link_frame = Frame(name=link_name + '_frame',
-                      link=Link(
-                          name=link_name, 
-                          offset=Transform(), 
-                          visual=Visual(), 
-                          collision=Collision()))
+                           link=Link(
+                           name=link_name, 
+                           offset=Transform(), 
+                           visual=Visual(), 
+                           collision=Collision()))
 
         URDF_Link.set_visual(elem_link, link_frame)
         URDF_Link.set_collision(elem_link, link_frame)
@@ -221,11 +221,11 @@ class URDFModel(RobotModel):
         attrib = elem_joint.attrib
         joint_name = attrib.get('name', 'joint_' + str(idx))
         joint_frame = Frame(name=joint_name + '_frame',
-                      joint=Joint(
-                          name=joint_name, 
-                          offset=Transform(), 
-                          dtype=attrib['type'], 
-                          limit=[None, None]))
+                            joint=Joint(
+                            name=joint_name, 
+                            offset=Transform(), 
+                            dtype=attrib['type'], 
+                            limit=[None, None]))
 
         parent_tag = elem_joint.find('parent')
         joint_frame.joint.parent = parent_tag.attrib['link']
@@ -298,36 +298,6 @@ class URDFModel(RobotModel):
             assert (ret != None), f"Not Found {name}, please check the name again"
             return ret
 
-    def _get_actuated_joint_names(self):
-        """
-        Return the name of the actuated joint(revolute, prismatic)
-
-        Returns:
-            list: Append joint if joint's dof is not zero
-        """
-        if self.root is not None:
-            joint_names = []
-            joint_names =  self._get_all_actuated_joint_names_recursive(joint_names, self.root)
-        return joint_names
-
-
-    # @staticmethod
-    # def _get_desired_actuated_joint_names(desired_frames):
-    #     """
-    #     Return the name of desired actuated joint(revolute, prismatic)
-
-    #     Args:
-    #         desired_frames (list): desired actuated joint names
-
-    #     Returns:
-    #         list: Append joint if joint's dof is not zero
-    #     """
-    #     joint_names = []
-    #     for f in desired_frames:
-    #         if f.joint.num_dof != 0:
-    #             joint_names.append(f.joint.name)
-    #     return joint_names
-    
     def _get_revolute_joint_names(self, frame):
         """
         Return the name of the actuated joint(revolute, prismatic)
