@@ -61,8 +61,8 @@ def convert_thetas_to_dict(active_joint_names, thetas):
     """
     if not isinstance(thetas, dict):
         assert len(active_joint_names) == len(thetas
-        ), f"""the number of joints is {len(active_joint_names)}, 
-                but the number of joint's angle is {len(thetas)}"""
+        ), f"""the number of robot joint's angle is {len(active_joint_names)}, 
+                but the number of input joint's angle is {len(thetas)}"""
         thetas = dict((j, thetas[i]) for i, j in enumerate(active_joint_names))        
     return thetas
 
@@ -116,29 +116,31 @@ def calc_pose_error(tar_pose, cur_pose, EPS):
     Returns:
         np.array: Returns pose error
     """
-    def rot_to_omega(R):
-        # referred p36
-        el = np.array(
-                [[R[2, 1] - R[1, 2]],
-                [R[0, 2] - R[2, 0]],
-                [R[1, 0] - R[0, 1]]]
-        )
-        norm_el = np.linalg.norm(el)
-        if norm_el > EPS:
-            w = np.dot(np.arctan2(norm_el, np.trace(R) - 1) / norm_el, el)
-        elif (R[0, 0] > 0 and R[1, 1] > 0 and R[2, 2] > 0):
-            w = np.zeros((3, 1))
-        else:
-            w = np.dot(np.pi/2, np.array([[R[0, 0] + 1], [R[1, 1] + 1], [R[2, 2] + 1]]))
-        return w
 
     pos_err = np.array([tar_pose[:3, -1] - cur_pose[:3, -1]])
     rot_err = np.dot(cur_pose[:3, :3].T, tar_pose[:3, :3])
-    w_err = np.dot(cur_pose[:3, :3], rot_to_omega(rot_err))
+    w_err = np.dot(cur_pose[:3, :3], rot_to_omega(rot_err, EPS))
 
     return np.vstack((pos_err.T, w_err))
 
 
+def rot_to_omega(R, EPS):
+    # referred p36
+    el = np.array(
+            [[R[2, 1] - R[1, 2]],
+            [R[0, 2] - R[2, 0]],
+            [R[1, 0] - R[0, 1]]]
+    )
+    norm_el = np.linalg.norm(el)
+    if norm_el > EPS:
+        w = np.dot(np.arctan2(norm_el, np.trace(R) - 1) / norm_el, el)
+    elif (R[0, 0] > 0 and R[1, 1] > 0 and R[2, 2] > 0):
+        w = np.zeros((3, 1))
+    else:
+        w = np.dot(np.pi/2, np.array([[R[0, 0] + 1], [R[1, 1] + 1], [R[2, 2] + 1]]))
+    return w
+
+
 def limit_joints(joint_angles, lower, upper):
     """
     Set joint angle limit
@@ -159,49 +161,3 @@ def limit_joints(joint_angles, lower, upper):
                 joint_angles[i] = upper[i]
     return joint_angles
 
-
-def get_robot_geom(link):
-    """
-    Get robot geometry from link
-
-    Args:
-        link (Link): robot's link
-
-    Returns:
-        name (str): geom's name
-        gtype: geom's type
-        gparam: geom's param
-    """
-    def get_cylinder_param(link):
-        radius = float(link.collision.gparam.get('radius'))
-        length = float(link.collision.gparam.get('length'))
-        return (radius, length)
-
-    def get_spehre_param(link):
-        radius = float(link.collision.gparam.get('radius'))
-        return radius
-
-    def get_box_param(link):
-        size = list(link.collision.gparam.get('size'))
-        return size
-
-    name = None
-    gtype = None
-    gparam = None
-
-    if link.collision.gtype == "cylinder":
-        name = link.name
-        gtype = link.collision.gtype
-        gparam = get_cylinder_param(link)
-    elif link.collision.gtype == "sphere":
-        name = link.name
-        gtype = link.collision.gtype
-        gparam = get_spehre_param(link)
-    elif link.collision.gtype == "box":
-        name = link.name
-        gtype = link.collision.gtype
-        gparam = get_box_param(link)
-
-    return name, gtype, gparam
-
-
